@@ -12,7 +12,7 @@
     Copyright 2004-2017 Game Maker 2k - http://gamemaker2k.org/
     iDB Installer made by Game Maker 2k - http://idb.berlios.net/
 
-    $FileInfo: setup.php - Last Update: 09/10/2018 SVN 867 - Author: cooldude2k $
+    $FileInfo: setup.php - Last Update: 06/23/2019 SVN 899 - Author: cooldude2k $
 */
 $File3Name = basename($_SERVER['SCRIPT_NAME']);
 if ($File3Name=="setup.php"||$File3Name=="/setup.php") {
@@ -68,6 +68,9 @@ fclose($fp);
 $fp = fopen("./settingsbak.php","w+");
 fwrite($fp, $BoardSettings);
 fclose($fp);
+$gettzinfofromjs = date_default_timezone_get();
+if(isset($_COOKIE['getusertz']) && in_array($_COOKIE['getusertz'], DateTimeZone::listIdentifiers())) {
+   $gettzinfofromjs = $_COOKIE['getusertz']; }
 // http://www.tutorialspoint.com/php/php_function_timezone_identifiers_list.htm
 $timezone_identifiers = DateTimeZone::listIdentifiers();
 //$timezone_identifiers = timezone_identifiers_list();
@@ -82,7 +85,6 @@ $zonelist['europe'] = array();
 $zonelist['indian'] = array();
 $zonelist['pacific'] = array();
 $zonelist['etcetera'] = array();
-$zonelist['others'] = array();
 for ($i=0; $i < count($timezone_identifiers); $i++) {
     $zonelookup = explode("/", $timezone_identifiers[$i]);
     if(count($zonelookup)==1) { array_push($zonelist['etcetera'], array($timezone_identifiers[$i], $timezone_identifiers[$i])); }
@@ -250,13 +252,13 @@ if(in_array("md2",hash_algos())) { ?>
 <?php } if(in_array("sha512",hash_algos())) { ?>
 <option value="sha512">SHA512</option>
 <?php } if(in_array("sha3-224",hash_algos())) { ?>
-<option value="sha3224">SHA3-224</option>
+<option value="sha3-224">SHA3-224</option>
 <?php } if(in_array("sha3-256",hash_algos())) { ?>
-<option value="sha3256">SHA3-256</option>
+<option value="sha3-256">SHA3-256</option>
 <?php } if(in_array("sha3-384",hash_algos())) { ?>
-<option value="sha3384">SHA3-384</option>
+<option value="sha3-384">SHA3-384</option>
 <?php } if(in_array("sha3-512",hash_algos())) { ?>
-<option value="sha3512">SHA3-512</option>
+<option value="sha3-512">SHA3-512</option>
 <?php } if(in_array("ripemd128",hash_algos())) { ?>
 <option value="ripemd128">RIPEMD128</option>
 <?php } if(in_array("ripemd160",hash_algos())) { ?>
@@ -280,7 +282,7 @@ if(!function_exists('hash')&&!function_exists('hash_algos')) { ?>
 <?php
 $optsel="";
 for ($i=0; $i < count($zonelist['africa']); $i++) {
-    if($User1TimeZone==$zonelist['africa'][$i][1]) { $optsel = " selected=\"selected\""; }
+    if($gettzinfofromjs==$zonelist['africa'][$i][1]) { $optsel = " selected=\"selected\""; }
     echo "<option".$optsel." value=\"".$zonelist['africa'][$i][1]."\">".str_replace("_", " ", $zonelist['africa'][$i][0])."</option>\n"; 
     $optsel=""; }
 ?>
@@ -289,7 +291,7 @@ for ($i=0; $i < count($zonelist['africa']); $i++) {
 <?php
 $optsel="";
 for ($i=0; $i < count($zonelist['america']); $i++) {
-    if($User1TimeZone==$zonelist['america'][$i][1]) { $optsel = " selected=\"selected\""; }
+    if($gettzinfofromjs==$zonelist['america'][$i][1]) { $optsel = " selected=\"selected\""; }
     echo "<option".$optsel." value=\"".$zonelist['america'][$i][1]."\">".str_replace("_", " ", $zonelist['america'][$i][0])."</option>\n"; 
     $optsel=""; }
 ?>
@@ -298,7 +300,7 @@ for ($i=0; $i < count($zonelist['america']); $i++) {
 <?php
 $optsel="";
 for ($i=0; $i < count($zonelist['antarctica']); $i++) {
-    if($User1TimeZone==$zonelist['antarctica'][$i][1]) { $optsel = " selected=\"selected\""; }
+    if($gettzinfofromjs==$zonelist['antarctica'][$i][1]) { $optsel = " selected=\"selected\""; }
     echo "<option".$optsel." value=\"".$zonelist['antarctica'][$i][1]."\">".str_replace("_", " ", $zonelist['antarctica'][$i][0])."</option>\n"; 
     $optsel=""; }
 ?>
@@ -307,7 +309,7 @@ for ($i=0; $i < count($zonelist['antarctica']); $i++) {
 <?php
 $optsel="";
 for ($i=0; $i < count($zonelist['arctic']); $i++) {
-    if($User1TimeZone==$zonelist['arctic'][$i][1]) { $optsel = " selected=\"selected\""; }
+    if($gettzinfofromjs==$zonelist['arctic'][$i][1]) { $optsel = " selected=\"selected\""; }
     echo "<option".$optsel." value=\"".$zonelist['arctic'][$i][1]."\">".str_replace("_", " ", $zonelist['arctic'][$i][0])."</option>\n"; 
     $optsel=""; }
 ?>
@@ -315,7 +317,7 @@ for ($i=0; $i < count($zonelist['arctic']); $i++) {
 <optgroup label="Asia">
 <?php
 for ($i=0; $i < count($zonelist['asia']); $i++) {
-    if($User1TimeZone==$zonelist['asia'][$i][1]) { $optsel = " selected=\"selected\""; }
+    if($gettzinfofromjs==$zonelist['asia'][$i][1]) { $optsel = " selected=\"selected\""; }
     echo "<option".$optsel." value=\"".$zonelist['asia'][$i][1]."\">".str_replace("_", " ", $zonelist['asia'][$i][0])."</option>\n"; 
     $optsel=""; }
 ?>
@@ -324,7 +326,7 @@ for ($i=0; $i < count($zonelist['asia']); $i++) {
 <?php
 $optsel="";
 for ($i=0; $i < count($zonelist['atlantic']); $i++) {
-    if($User1TimeZone==$zonelist['atlantic'][$i][1]) { $optsel = " selected=\"selected\""; }
+    if($gettzinfofromjs==$zonelist['atlantic'][$i][1]) { $optsel = " selected=\"selected\""; }
     echo "<option".$optsel." value=\"".$zonelist['atlantic'][$i][1]."\">".str_replace("_", " ", $zonelist['atlantic'][$i][0])."</option>\n"; 
     $optsel=""; }
 ?>
@@ -333,7 +335,7 @@ for ($i=0; $i < count($zonelist['atlantic']); $i++) {
 <?php
 $optsel="";
 for ($i=0; $i < count($zonelist['australia']); $i++) {
-    if($User1TimeZone==$zonelist['australia'][$i][1]) { $optsel = " selected=\"selected\""; }
+    if($gettzinfofromjs==$zonelist['australia'][$i][1]) { $optsel = " selected=\"selected\""; }
     echo "<option".$optsel." value=\"".$zonelist['australia'][$i][1]."\">".str_replace("_", " ", $zonelist['australia'][$i][0])."</option>\n"; 
     $optsel=""; }
 ?>
@@ -342,7 +344,7 @@ for ($i=0; $i < count($zonelist['australia']); $i++) {
 <?php
 $optsel="";
 for ($i=0; $i < count($zonelist['europe']); $i++) {
-    if($User1TimeZone==$zonelist['europe'][$i][1]) { $optsel = " selected=\"selected\""; }
+    if($gettzinfofromjs==$zonelist['europe'][$i][1]) { $optsel = " selected=\"selected\""; }
     echo "<option".$optsel." value=\"".$zonelist['europe'][$i][1]."\">".str_replace("_", " ", $zonelist['europe'][$i][0])."</option>\n"; 
     $optsel=""; }
 ?>
@@ -351,7 +353,7 @@ for ($i=0; $i < count($zonelist['europe']); $i++) {
 <?php
 $optsel="";
 for ($i=0; $i < count($zonelist['indian']); $i++) {
-    if($User1TimeZone==$zonelist['indian'][$i][1]) { $optsel = " selected=\"selected\""; }
+    if($gettzinfofromjs==$zonelist['indian'][$i][1]) { $optsel = " selected=\"selected\""; }
     echo "<option".$optsel." value=\"".$zonelist['indian'][$i][1]."\">".str_replace("_", " ", $zonelist['indian'][$i][0])."</option>\n"; 
     $optsel=""; }
 ?>
@@ -360,7 +362,7 @@ for ($i=0; $i < count($zonelist['indian']); $i++) {
 <?php
 $optsel="";
 for ($i=0; $i < count($zonelist['pacific']); $i++) {
-    if($User1TimeZone==$zonelist['pacific'][$i][1]) { $optsel = " selected=\"selected\""; }
+    if($gettzinfofromjs==$zonelist['pacific'][$i][1]) { $optsel = " selected=\"selected\""; }
     echo "<option".$optsel." value=\"".$zonelist['pacific'][$i][1]."\">".str_replace("_", " ", $zonelist['pacific'][$i][0])."</option>\n"; 
     $optsel=""; }
 ?>
@@ -369,7 +371,7 @@ for ($i=0; $i < count($zonelist['pacific']); $i++) {
 <?php
 $optsel="";
 for ($i=0; $i < count($zonelist['etcetera']); $i++) {
-    if($User1TimeZone==$zonelist['etcetera'][$i][1]) { $optsel = " selected=\"selected\""; }
+    if($gettzinfofromjs==$zonelist['etcetera'][$i][1]) { $optsel = " selected=\"selected\""; }
     echo "<option".$optsel." value=\"".$zonelist['etcetera'][$i][1]."\">".str_replace("_", " ", $zonelist['etcetera'][$i][0])."</option>\n"; 
     $optsel=""; }
 ?>
@@ -384,14 +386,14 @@ for ($i=0; $i < count($zonelist['etcetera']); $i++) {
 </tr><tr>
 	<td style="width: 50%;"><label class="TextBoxLabel" for="TestReferer">Test Referering URL:</label></td>
 	<td style="width: 50%;"><select id="TestReferer" name="TestReferer" class="TextBox">
-<option selected="selected" value="off">off</option>
-<option value="on">on</option>
+<option selected="selected" value="off">Off</option>
+<option value="on">On</option>
 </select></td>
 </tr><tr>
 	<td style="width: 50%;"><label class="TextBoxLabel" for="iDBHTTPLogger">Log Every HTTP Requests:</label></td>
 	<td style="width: 50%;"><select id="iDBHTTPLogger" name="iDBHTTPLogger" class="TextBox">
-<option value="off">off</option>
-<option value="on">on</option>
+<option value="off">Off</option>
+<option value="on">On</option>
 </select></td>
 </tr><tr>
 	<td style="width: 50%;"><label class="TextBoxLabel" for="iDBLoggerFormat">Insert The Format for HTTP Logger:</label></td>
@@ -421,8 +423,8 @@ if ($handle = opendir($skindir)) { $dirnum = null;
 </tr><tr>
 	<td style="width: 50%;"><label class="TextBoxLabel" for="SQLThemes">Store Themes in SQL Database:</label></td>
 	<td style="width: 50%;"><select id="SQLThemes" name="SQLThemes" class="TextBox">
-<option selected="selected" value="off">off</option>
-<option value="on">on</option>
+<option selected="selected" value="off">Off</option>
+<option value="on">On</option>
 </select></td>
 </tr><tr>
 	<td style="width: 50%;"><label class="TextBoxLabel" title="Might not work" for="unlink">Delete Installer?</label></td>
